#! /usr/bin/env python3
""" Configuration for classes Hub, InfluxDB, Inverter, RDBMS, Heating """

import datetime
import os

DEBUG = os.environ.get('DEBUG', False)
number_of_lines_before_next_header = 30

class ConfigHub:
    u""" Třída s konfigurací pro hub (rpi04.navratil.lan) """
    def __init__(self):
        self._ip = "192.168.4.9"
        self._port = 8083
        self._timeout = 10
        self._user = "rh"
        self._password = "8IvOvEnoy5dqm/cKCy0q"

    @property
    def host(self):
        return self._ip

    @property
    def port(self):
        return self._port

    @property
    def user(self):
        return self._user

    @property
    def password(self):
        return self._password

    @property
    def timeout(self):
        return self._timeout

class ConfigInfluxDB:
    u""" Třída s konfigurací pro InfluxDB """
    def __init__(self):
        self._ip = "192.168.4.9"
        self._port = 8086
        self._database = 'zwave'

    @property
    def host(self):
        return self._ip

    @property
    def port(self):
        return self._port

    @property
    def database(self):
        return self._database

class ConfigInverter:
    u""" Třída s konfigurací pro Fronius střídač """
    def __init__(self):
        self._ip = "192.168.4.8"
        self._timeout = 3

    @property
    def host(self):
        return self._ip

    @property
    def timeout(self):
        return self._timeout

class ConfigRDBMS:
    u""" Třída s konfigurací pro PostgreSQL RDBMS """
    def __init__(self):
        self._ip = "192.168.4.52"
        self._database = "rh"
        self._user = "script01"
        self._password = "4bOS_vTtcPnsLbc0G15j"

    @property
    def host(self):
        return self._ip

    @property
    def database(self):
        return self._database

    @property
    def user(self):
        return self._user

    @property
    def password(self):
        return self._password

class ConfigHeating:
    u""" Třída s konfigurací pro vytápění """
    def __init__(self):
        self._heating_season = True
        self._maximum_of_mismatches = 10
        # lowest safe temperature during heating season (at least 5°C)
        self._frost_protection = 5
        # bude dům vytápěn pro ženu?
        # pro ženy jsou teploty pro vytápění posunuty o 1°C nahoru
        self._thermal_comfort_for_women = True
        if self._thermal_comfort_for_women:
            self._heating_max_temperature = 21
            self._heating_min_temperature = 20
        else:
            self._heating_max_temperature = 20
            self._heating_min_temperature = 19
        # interval pro vytápění o víkendu
        self._heating_during_weekend = (
            (datetime.time(4, 00), datetime.time(21, 00)),
        )
        # intervaly pro vytápění v pracovní dny
        self._heating_during_working_day = (
            (datetime.time(4, 00), datetime.time(7, 30)),
            (datetime.time(12, 00), datetime.time(20, 30)),
        )
        # vytápění pro státní svátek v pracovní den nebo pro práci z domova
        # tuple je doplňováno a zkracováno
        self._heating_in_these_weekdays = (
            datetime.date(2020, 12, 7),
            datetime.date(2020, 12, 8),
            datetime.date(2020, 12, 9),
            datetime.date(2020, 12, 10),
            datetime.date(2020, 12, 11),
        )
        # nikdo doma, nevytápět
        self._no_heating_in_these_days = (
            datetime.date(2020, 12, 1),
            datetime.date(2020, 12, 2),
            datetime.date(2020, 12, 3),
            datetime.date(2020, 12, 4),
            datetime.date(2020, 12, 5),
        )

    @property
    def maximum_of_mismatches(self):
        return self._maximum_of_mismatches

    @property
    def is_heating_season(self):
        return self._heating_season

    @property
    def frost_protection(self):
        return self._frost_protection

    @property
    def heating_min_temperature(self):
        return self._heating_min_temperature

    @property
    def heating_max_temperature(self):
        return self._heating_max_temperature

    @property
    def intervals_for_heating(self):
        _now = datetime.datetime.now()
        # is today an exception? (no heating)
        if _now.date() in self._no_heating_in_these_days:
            if DEBUG:
                print("no heating today (no intervals for heating)")
            return tuple()
        # is today other exception? (public holiday in a weekday)
        if _now.date() in self._heating_in_these_weekdays:
            if DEBUG:
                print("intervals for heating", self._heating_during_weekend)
            return self._heating_during_weekend

        # is now weekend?
        # public holidays are not covered
        if _now.weekday() > 4:
            # weekend
            return self._heating_during_weekend
        else:
            # working day
            return self._heating_during_working_day
