# rpi03

Raspberry Pi 3 Model B Plus Rev 1.3 počítač (BCM2835, revize a020d3, 4x ARMv7 Processor rev 4, 44.80 BogoMIPS) s Raspbian GNU/Linux 10 (buster) `rpi03.navratil.lan` s IPv4 adresou 192.168.4.52.

Obsahuje PostgreSQL RDBMS verze 11.9, do které jsou od 01.01.2020 ukládány denní extrémy.

## Využití z řídící aplikace

V řídící aplikaci se používá modul `postgres.py`.

## Manuální přístup

Prohlížení uložených dat je možné pomocí `psql`.

```shell
psql -h 192.168.4.52 -U navratil -d rh
psql (11.9 (Raspbian 11.9-0+deb10u1))
SSL spojení (protokol: TLSv1.3, šifra: TLS_AES_256_GCM_SHA384, bitů: 256, komprese: vypnuto)
Pro získání nápovědy napište "help".
```

## Seznam relací

```shell
rh=# \dt+
                                         Seznam relací
 Schéma |     Jméno     |   Typ   | Vlastník | Velikost |                Popis                 
--------+---------------+---------+----------+----------+--------------------------------------
 public | baterie_max   | tabulka | navratil | 56 kB    | denní maxima nabití baterie
 public | baterie_min   | tabulka | navratil | 56 kB    | denní minima nabití baterie
 public | do_site_max   | tabulka | navratil | 56 kB    | denní maxima dodávky do sítě
 public | stridac       | tabulka | navratil | 11 GB    | JSON pro střídač
 public | vyroba_max    | tabulka | navratil | 56 kB    | denní maximální výroba z FVE
 public | vyroba_rozsah | tabulka | navratil | 0 bytes  | denní časový rozsah výroby z FVE
 public | ze_site_min   | tabulka | navratil | 56 kB    | denní minima odběru (nákupu) ze sítě
(7 řádek)
```

## Pět dní s plně nabitým akumulátorem

```shell
rh=# \d baterie_max
                                    Tabulka "public.baterie_max"
 Sloupec |           Typ            | Collation | Nullable |               Implicitně                
---------+--------------------------+-----------+----------+-----------------------------------------
 id      | integer                  |           | not null | nextval('baterie_max_id_seq'::regclass)
 mtime   | timestamp with time zone |           | not null | CURRENT_TIMESTAMP
 hodnota | smallint                 |           |          | 0
Indexy:
    "baterie_max_pkey" PRIMARY KEY, btree (id)
```

```shell
rh=# SELECT mtime, hodnota FROM baterie_max ORDER BY hodnota DESC LIMIT 5;
             mtime             | hodnota 
-------------------------------+---------
 2020-03-16 11:38:45.048068+01 |    7200
 2020-03-31 13:34:32.242943+02 |    7200
 2020-04-06 10:50:07.205252+02 |    7200
 2020-04-28 11:59:13.229487+02 |    7200
 2020-02-22 12:38:55.956445+01 |    7200
(5 řádek)
```

## Dvacet dnů s rekordem výroby

```shell
rh=# \d vyroba_max
                                    Tabulka "public.vyroba_max"
 Sloupec |           Typ            | Collation | Nullable |               Implicitně               
---------+--------------------------+-----------+----------+----------------------------------------
 id      | integer                  |           | not null | nextval('vyroba_max_id_seq'::regclass)
 mtime   | timestamp with time zone |           | not null | CURRENT_TIMESTAMP
 hodnota | smallint                 |           |          | 0
Indexy:
    "vyroba_max_pkey" PRIMARY KEY, btree (id)
```

```shell
rh=# SELECT mtime, hodnota FROM vyroba_max ORDER BY hodnota DESC LIMIT 20;
             mtime             | hodnota 
-------------------------------+---------
 2020-06-06 12:27:18.140169+02 |    8045
 2020-05-26 12:33:20.376929+02 |    7873
 2020-05-02 13:49:22.312084+02 |    7860
 2020-05-25 12:41:15.724667+02 |    7839
 2020-07-09 12:43:57.395054+02 |    7724
 2020-05-22 12:15:41.971879+02 |    7681
 2020-07-06 12:26:25.651268+02 |    7566
 2020-05-06 12:04:49.405028+02 |    7560
 2020-07-18 11:00:21.628374+02 |    7491
 2020-05-28 14:07:26.104898+02 |    7479
 2020-04-25 11:48:33.336468+02 |    7444
 2020-08-27 11:52:33.657432+02 |    7313
 2020-05-03 10:54:44.965609+02 |    7284
 2020-06-05 12:52:57.727941+02 |    7181
 2020-07-17 11:40:31.971685+02 |    7143
 2020-06-25 12:35:35.554351+02 |    7138
 2020-05-14 12:50:18.921311+02 |    7108
 2020-04-14 12:03:28.277423+02 |    7078
 2020-07-03 13:38:57.753374+02 |    7078
 2020-05-23 12:59:50.163252+02 |    6990
(20 řádek)
```
