#! /usr/bin/env python3
u""" Modul pro práci s PostgreSQL RDBMS """

import json
import sys
import os
import psycopg2
import psycopg2.sql

DEBUG = os.environ.get('DEBUG', False)


class RDBMS:
    u""" Třída pro práci s PostgreSQL RDBMS """
    def __init__(self, host, database, user, password):
        self._host = host
        self._database = database
        self._user = user
        self._password = password

        try:
            self._conn = psycopg2.connect(
                host=self._host,
                database=self._database,
                user=self._user,
                password=self._password
            )
            self._cur = self._conn.cursor()
        except psycopg2.DatabaseError as e:
            if self._conn:
                self._conn.rollback()
            print(e)
            sys.exit

        assert self._cur, "self._cur is not set"

    def close(self):
        self._conn.close()

    def _print(self):
        print("PostgreSQL host is {}".format(self._host))
        print(self._database)
        print(self._user)
        print(self._password)
        print(self._conn)
        print(self._cur)

    def save(self, table, value):
        updated_rows = inserted_rows = 0
        sql_update = """UPDATE {}
        SET hodnota = %s, mtime=CURRENT_TIMESTAMP
        WHERE DATE(mtime) = DATE(now())"""
        sql_insert = """INSERT INTO {}
        (hodnota) VALUES (%s)"""
        t = (value, )
        query = psycopg2.sql.SQL(sql_update).format(
                    psycopg2.sql.Identifier(table)
                )
        if DEBUG:
            print(query.as_string(self._conn))
        self._cur.execute(query, t)
        updated_rows = self._cur.rowcount
        if not updated_rows:
            query = psycopg2.sql.SQL(sql_insert).format(
                        psycopg2.sql.Identifier(table)
                    )
            if DEBUG:
                print(query.as_string(self._conn))
            self._cur.execute(query, t)
            inserted_rows = self._cur.rowcount
        if DEBUG:
             print("Rows updated {} / inserted {}".format(updated_rows, inserted_rows))
             print(sql_update)
             print(sql_insert)
             print(t)
        self._conn.commit()

    def save_power_flow_realtime_data(self, data):
        inserted_rows = 0
        sql_insert = """INSERT INTO stridac
        (power_flow_realtime_data) VALUES (%s)"""
        t = [json.dumps(data)]
        self._cur.execute(sql_insert, t)
        inserted_rows = self._cur.rowcount
        if DEBUG:
             print("Rows inserted {}".format(inserted_rows))
             print(sql_insert)
             print(t)
        self._conn.commit()

    def load(self, table, initial_value):
        sql_select = "SELECT w FROM {} WHERE DATE(mtime) = DATE(now());"
        rows = self._cur.execute(
            psycopg2.sql.SQL(sql_select).format(psycopg2.sql.Identifier(table))
        )
        # check, if rows have number of rows, and assert > 1
        # shall be only one or none
        row = cursor.fetchall()
        if row:
            return row[0]
        else:
            return initial_value

    def execute_sql(self, sql, t):
        u""" Provede SQL příkaz, potvrdí ho a vrátí počet aktualizovaných resp. vložených řádků """
        self._cur.execute(sql, t)
        self._conn.commit()
        return self._cur.rowcount
